From 15a2b3168f1b38995f8c031528c76d211ba83e32 Mon Sep 17 00:00:00 2001
From: Greg Burd <greg@burd.me>
Date: Tue, 6 May 2025 10:59:13 -0400
Subject: [PATCH v1 1/3] Fix references in comments in
 heap_page_is_all_visible().

Update comments to reference the function heap_page_prune_and_freeze()
rather than lazy_scan_prune() resulting from the changes in 6dbb490.

Author: Greg Burd <greg@burd.me>
---
 src/backend/access/heap/vacuumlazy.c | 10 +++++-----
 1 file changed, 5 insertions(+), 5 deletions(-)

diff --git a/src/backend/access/heap/vacuumlazy.c b/src/backend/access/heap/vacuumlazy.c
index f28326bad09..e450911424f 100644
--- a/src/backend/access/heap/vacuumlazy.c
+++ b/src/backend/access/heap/vacuumlazy.c
@@ -3606,10 +3606,10 @@ dead_items_cleanup(LVRelState *vacrel)
  * xmin amongst the visible tuples.  Set *all_frozen to true if every tuple
  * on this page is frozen.
  *
- * This is a stripped down version of lazy_scan_prune().  If you change
- * anything here, make sure that everything stays in sync.  Note that an
- * assertion calls us to verify that everybody still agrees.  Be sure to avoid
- * introducing new side-effects here.
+ * This is a stripped down version of heap_page_prune_and_freeze() called by
+ * lazy_scan_prune().  If you change anything here, make sure that everything
+ * stays in sync.  Note that an assertion calls us to verify that everybody
+ * still agrees.  Be sure to avoid introducing new side-effects here.
  */
 static bool
 heap_page_is_all_visible(LVRelState *vacrel, Buffer buf,
@@ -3670,7 +3670,7 @@ heap_page_is_all_visible(LVRelState *vacrel, Buffer buf,
 				{
 					TransactionId xmin;
 
-					/* Check comments in lazy_scan_prune. */
+					/* Check comments in heap_page_prune_and_freeze(). */
 					if (!HeapTupleHeaderXminCommitted(tuple.t_data))
 					{
 						all_visible = false;
-- 
2.39.5 (Apple Git-154)

